% Ministerio de Hacienda - Cálculo del PIB potencial a través FMV
% Coordinación Macroeconómica

%Declaring variables
var y ytend ygap g_ytend infl u u_lp u_gap g_ulp infl_e;     
varexo w_ytend w_gytend w_ygap e_infl w_ulp w_gulp w_ugap e_infle;

%Declaring parameter values
parameters theta phi lambda tau_1 tau_2 tau_3 tau_4 beta g_ss u_ss rho;

%Intitializing parameter values
theta=0.3;
g_ss=0.0073;
u_ss=0.073;
tau_3=0.1;
tau_4=0.1;
rho=0.9;

%Model equations
model;
ygap = y - ytend ;                                                          
ytend = ytend(-1) + g_ytend + w_ytend;                                      
g_ytend = theta*g_ss + (1-theta)*g_ytend(-1) + w_gytend;                    
ygap = phi*ygap(-1) + w_ygap;                                               
infl = lambda*infl_e+(1-lambda)*infl(-1) + beta*ygap + e_infl;              
u_lp = tau_4*u_ss + (1-tau_4)*u_lp(-1) + g_ulp + w_ulp;                     
g_ulp = (1-tau_3)*g_ulp(-1) + w_gulp;
u_gap = tau_2*u_gap(-1) + tau_1*ygap + w_ugap;
u_gap = u_lp - u;
infl_e = rho*infl_e(-1) + e_infle;
end;

steady_state_model;
ytend = 11;
y = 11;
ygap=0;
infl = 0.03;
infl_e = 0.03;
g_ytend = g_ss;
g_ulp = 0;
u_lp = u_ss;
u = u_lp;
u_gap=0;
end;

steady(nocheck); // Acá no se testea el estado estacionario por que se lo definimos previamente. 

shocks;
var w_ytend; stderr 0.009;
var w_gytend; stderr 0.0005;
var w_ygap; stderr 0.022;
var w_ulp; stderr 0.01;
var w_gulp; stderr 0.001;
var w_ugap; stderr 0.01;
var e_infl; stderr 0.03;
var e_infle; stderr 0.03;
end;

varobs infl y u infl_e;

estimated_params;
theta, 0.5, 0.0001, 10;
phi, 0.5, -10, 10;
lambda, 2, -10, 10;
beta, 0.5, -10, 10;
rho, 0.5, -10, 10;
tau_1, 0.5, -10, 10;
tau_2, 0.5, -10, 10;
tau_3, 0.5, -10, 10;
tau_4, 0.5, -10, 0.99;
%stderr w_gytend, 0.1, 0.01, 0.1;
%stderr w_ytend, 0.1, 0.01, 0.1;
%stderr w_ygap, 0.1, 0.01, 0.1;
%stderr w_ulp, 0.1, 0.01, 0.1;
%stderr w_gulp, 0.1, 0.01, 0.1;
%stderr w_ugap, 0.1, 0.01, 0.1;
%stderr e_infl, 0.1, 0.01, 0.1;
%stderr e_infle, 0.1, 0.01, 0.1;
end;

%estimated_params_init(use_calibration);

%end;

model_diagnostics;

estimation(datafile='FMV.xlsx',diffuse_filter,mode_compute=5) ytend ygap y;

ypot = oo_.SmoothedVariables.ytend;

xlswrite('pib_pot.xlsx',ypot)

 